@@ -7,7 +7,7 @@ use strict;
 use Fcntl ':flock';
 
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 use constant PREFIX => '.lock.';
@@ -179,30 +179,46 @@ sub lockstate {
 
 __END__
 
+
+
 =head1 NAME
 
-Data::Conveyor - stage-based conveyor-belt-like ticket handling system
+Data::Conveyor::Lock - stage-based conveyor-belt-like ticket handling system
 
 =head1 SYNOPSIS
 
-None yet (see below).
+    Data::Conveyor::Lock->new;
 
 =head1 DESCRIPTION
 
 None yet. This is an early release; fully functional, but undocumented. The
 next release will have more documentation.
 
+=head1 METHODS
+
+=over 4
+
+
+
+=back
+
+Data::Conveyor::Lock inherits from .
+
 =head1 TAGS
 
 If you talk about this module in blogs, on del.icio.us or anywhere else,
 please use the C<dataconveyor> tag.
 
+=head1 VERSION 
+                   
+This document describes version 0.02 of L<Data::Conveyor::Lock>.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-data-conveyor@rt.cpan.org>, or through the web interface at
+C<<bug-data-conveyor@rt.cpan.org>>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -229,10 +245,11 @@ Heinz Ekker C<< <ek@univie.ac.at> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+
 =cut
 
